@@ -122,23 +122,28 @@ muleMan <- structure(function#Multilevel dendroclimatic correlograms
     ## Modeling tree-biomass fluctuations while accounting for
     ## within-plot source variability (see defaults in "modelFrame"
     ## function)
-    trwf <- modelFrame(Pchron,
-                       to = 'cm',
-                       MoreArgs = list(mp = c(2,1, biom_param)),
-                       log.t = FALSE,
-                       on.time = FALSE)
+    ## /donttest{
+    ## trwf <- modelFrame(Pchron,
+    ##                    to = 'cm',
+    ##                    MoreArgs = list(mp = c(2,1, biom_param)),
+    ##                    log.t = FALSE,
+    ##                    on.time = FALSE)
+    ## }
     ## Climatic Records:
     data(Temp,envir = environment())
     data(Prec,envir = environment())
     ## Aridity-index fluctuations:
-    aif <- modelFrame(rd = list(Prec, Temp),
-                      fn = list('moveYr','wlai'),
-                      lv = list('year','year'),
-                      form = 'lmeForm')
-
+    ## /donttest{
+    ##     aif <- modelFrame(rd = list(Prec, Temp),
+    ##                       fn = list('moveYr','wlai'),
+    ##                       lv = list('year','year'),
+    ##                       form = 'lmeForm')
+    ## }
     ##Multivariate comparison:
-    mcomp <- muleMan(trwf,
-                        aif,
-                     nperm = 10^3)
-    str(mcomp)
+    ## /donttest{
+    ## mcomp <- muleMan(trwf,
+    ##                     aif,
+    ##                  nperm = 10^3)
+    ## str(mcomp)
+    ## }
     })
