@@ -21,11 +21,13 @@ summary.modelFrame <- structure(function #summarize a modelFrame object
 
     ## Modeling tree-biomass fluctuations while accounting for
     ## within-plot source variability (see defaults in "modelFrame"
-    ## function)
-    trwf <- modelFrame(Pchron,
-                       to = 'cm',
-                       MoreArgs = list(mp = c(2,1, biom_param)),
-                       log.t = TRUE,
-                       on.time = TRUE)
-    summary(trwf)
+    ## function):
+    ## \donttest{
+    ## trwf <- modelFrame(Pchron,
+    ##                    to = 'cm',
+    ##                    MoreArgs = list(mp = c(2,1, biom_param)),
+    ##                    log.t = TRUE,
+    ##                    on.time = TRUE)
+    ## summary(trwf)
+    ## }
 })
